@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # The internetarchive module is a Python/CLI interface to Archive.org.
 #
@@ -24,18 +23,18 @@ internetarchive.iarequest
 :copyright: (C) 2012-2021 by Internet Archive.
 :license: AGPL 3, see LICENSE for more details.
 """
-import re
 import copy
 import logging
+import re
 from urllib.parse import quote
-import requests.models
+
 import requests
+import requests.models
 from jsonpatch import make_patch
 
-from internetarchive import auth, __version__
-from internetarchive.utils import json, needs_quote, delete_items_from_dict
+from internetarchive import __version__, auth
 from internetarchive.exceptions import ItemLocateError
-
+from internetarchive.utils import delete_items_from_dict, json, needs_quote
 
 logger = logging.getLogger(__name__)
 
@@ -176,7 +175,7 @@ class MetadataRequest(requests.models.Request):
 
         if not self.auth:
             self.auth = auth.S3PostAuth(access_key, secret_key)
-        metadata = {} if not metadata else metadata
+        metadata = metadata or {}
 
         self.metadata = metadata
         self.source_metadata = source_metadata
@@ -211,7 +210,7 @@ class MetadataRequest(requests.models.Request):
 
 class MetadataPreparedRequest(requests.models.PreparedRequest):
     def prepare(self, method=None, url=None, headers=None, files=None, data=None,
-                params=None, auth=None, cookies=None, hooks=None, metadata={},
+                params=None, auth=None, cookies=None, hooks=None, metadata={},  # noqa: B006
                 source_metadata=None, target=None, priority=None, append=None,
                 append_list=None):
         self.prepare_method(method)
@@ -229,7 +228,7 @@ class MetadataPreparedRequest(requests.models.PreparedRequest):
 
     def prepare_body(self, metadata, source_metadata, target, priority, append,
                      append_list):
-        priority = -5 if not priority else priority
+        priority = priority or -5
 
         if not source_metadata:
             r = requests.get(self.url)
@@ -330,7 +329,7 @@ def prepare_target_patch(metadata, source_metadata, append, target, append_list,
         if not lst:
             return value
         sub_dict = dictify(lst[1:], key, value)
-        for i, v in enumerate(lst):
+        for v in lst:
             md = {v: copy.deepcopy(sub_dict)}
             return md
 
@@ -453,9 +452,9 @@ def prepare_metadata(metadata, source_metadata=None, append=False, append_list=F
             for k in metadata:
                 if not get_index(k):
                     continue
-                elif not rm_index(k) == key:
+                elif rm_index(k) != key:
                     continue
-                elif not metadata[k] == 'REMOVE_TAG':
+                elif metadata[k] != 'REMOVE_TAG':
                     continue
                 else:
                     indexes.append(get_index(k))
