@@ -25,6 +25,7 @@ internetarchive.item
 """
 from __future__ import annotations
 
+import io
 import math
 import os
 import sys
@@ -341,7 +342,7 @@ class Item(BaseItem):
 
         :param reduced_priority: Submit your derive at a lower priority.
                                  This option is helpful to get around rate-limiting.
-                                 Your task will more likey be accepted, but it might
+                                 Your task will more likely be accepted, but it might
                                  not run for a long time. Note that you still may be
                                  subject to rate-limiting.
 
@@ -381,7 +382,7 @@ class Item(BaseItem):
 
         :param reduced_priority: Submit your derive at a lower priority.
                                  This option is helpful to get around rate-limiting.
-                                 Your task will more likey be accepted, but it might
+                                 Your task will more likely be accepted, but it might
                                  not run for a long time. Note that you still may be
                                  subject to rate-limiting. This is different than
                                  ``priority`` in that it will allow you to possibly
@@ -426,7 +427,7 @@ class Item(BaseItem):
 
         :param reduced_priority: Submit your derive at a lower priority.
                                  This option is helpful to get around rate-limiting.
-                                 Your task will more likey be accepted, but it might
+                                 Your task will more likely be accepted, but it might
                                  not run for a long time. Note that you still may be
                                  subject to rate-limiting. This is different than
                                  ``priority`` in that it will allow you to possibly
@@ -463,7 +464,7 @@ class Item(BaseItem):
 
         :param reduced_priority: Submit your derive at a lower priority.
                                  This option is helpful to get around rate-limiting.
-                                 Your task will more likey be accepted, but it might
+                                 Your task will more likely be accepted, but it might
                                  not run for a long time. Note that you still may be
                                  subject to rate-limiting. This is different than
                                  ``priority`` in that it will allow you to possibly
@@ -492,11 +493,18 @@ class Item(BaseItem):
         r.raise_for_status()
         return r
 
-    def delete_review(self) -> Response:
+    def delete_review(self, username=None, screenname=None, itemname=None) -> Response:
         u = f'{self.session.protocol}//{self.session.host}/services/reviews.php'
         p = {'identifier': self.identifier}
+        d = None
+        if username:
+            d = {'username': username}
+        elif screenname:
+            d = {'screenname': screenname}
+        elif itemname:
+            d = {'itemname': itemname}
         a = S3Auth(self.session.access_key, self.session.secret_key)
-        r = self.session.delete(u, params=p, auth=a)
+        r = self.session.delete(u, params=p, data=d, auth=a)
         r.raise_for_status()
         return r
 
@@ -525,9 +533,11 @@ class Item(BaseItem):
                   files: File | list[File] | None = None,
                   formats: str | list[str] | None = None,
                   glob_pattern: str | None = None,
+                  exclude_pattern: str | None = None,
                   on_the_fly: bool = False):
         files = files or []
         formats = formats or []
+        exclude_pattern = exclude_pattern or ''
         on_the_fly = bool(on_the_fly)
 
         if not isinstance(files, (list, tuple, set)):
@@ -561,14 +571,20 @@ class Item(BaseItem):
                     patterns = glob_pattern.split('|')
                 else:
                     patterns = glob_pattern
+                if not isinstance(exclude_pattern, list):
+                    exclude_patterns = exclude_pattern.split('|')
+                else:
+                    exclude_patterns = exclude_pattern
                 for p in patterns:
                     if fnmatch(f.get('name', ''), p):
-                        yield self.get_file(str(f.get('name')))
+                        if not any(fnmatch(f.get('name', ''), e) for e in exclude_patterns):
+                            yield self.get_file(str(f.get('name')))
 
     def download(self,
                  files: File | list[File] | None = None,
                  formats: str | list[str] | None = None,
                  glob_pattern: str | None = None,
+                 exclude_pattern: str | None = None,
                  dry_run: bool = False,
                  verbose: bool = False,
                  ignore_existing: bool = False,
@@ -593,6 +609,9 @@ class Item(BaseItem):
         :param glob_pattern: Only download files matching the given
                              glob pattern.
 
+        :param exclude_pattern: Exclude files whose filename matches the given
+                                glob pattern.
+
         :param dry_run: Output download URLs to stdout, don't
                         download anything.
 
@@ -672,7 +691,11 @@ class Item(BaseItem):
         if formats:
             files = self.get_files(formats=formats, on_the_fly=on_the_fly)
         if glob_pattern:
-            files = self.get_files(glob_pattern=glob_pattern, on_the_fly=on_the_fly)
+            files = self.get_files(
+                glob_pattern=glob_pattern,
+                exclude_pattern=exclude_pattern,
+                on_the_fly=on_the_fly
+            )
 
         errors = []
         downloaded = 0
@@ -957,7 +980,16 @@ class Item(BaseItem):
                                               dynamic_ncols=True,
                                               total=expected_size,
                                               unit='MiB')
-                    data = IterableToFileAdapter(progress_generator, size)
+                    data = None
+                    # pre_encode is needed because http doesn't know that it
+                    # needs to encode a TextIO object when it's wrapped
+                    # in the Iterator from tqdm.
+                    # So, this FileAdapter provides pre-encoded output
+                    data = IterableToFileAdapter(
+                        progress_generator,
+                        size,
+                        pre_encode=isinstance(body, io.TextIOBase)
+                    )
                 except Exception:
                     print(f' uploading {key}', file=sys.stderr)
                     data = body
